package net.wanji.opt.common;

import com.alibaba.fastjson.JSONArray;
import net.wanji.opt.constant.DirEnum;
import org.apache.commons.lang3.StringUtils;

import java.time.LocalTime;
import java.time.format.DateTimeFormatter;
import java.time.temporal.ChronoUnit;

/**
 * @author duanruiming
 * @date 2025/04/02 15:44
 */
public class CommonUtils {

    /**
     * 分隔符：下划线
     **/
    public static final String SEPARATOR_UNDER_LINE = "_";

    public static String getStrJoin(String... str) {
        String join = String.join(SEPARATOR_UNDER_LINE, str);
        return join;
    }

    /**
     * 事件发生方向转换为描述
     *
     * @param dir
     * @return
     */
    public static String getEventHappenDirName(String dir) {
        StringBuilder stringBuilder = new StringBuilder();
        if (StringUtils.isNotEmpty(dir)) {
            JSONArray dirArr = JSONArray.parseArray(dir);
            for (int i = 0; i < dirArr.size(); i++) {
                String dirName = DirEnum.getName(dirArr.getString(i));
                stringBuilder.append(",");
                stringBuilder.append(dirName);
            }
        }
        if (stringBuilder.length() > 1) {
            return stringBuilder.substring(1);
        }
        return null;
    }

    /**
     * 获取两个时间之间相差多少分钟
     * @param startTime
     * @param endTime
     * @param format
     * @return
     */
    public static int getTimeBetweenMinutes(String startTime, String endTime, String format) {
        // 定义时间格式
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern(format);
        // 解析时间字符串为LocalTime对象
        LocalTime time1 = LocalTime.parse(startTime, formatter);
        LocalTime time2 = LocalTime.parse(endTime, formatter);
        // 计算时间差（以分钟为单位）
        int minutes = (int) ChronoUnit.MINUTES.between(time1, time2);
        return minutes;
    }

}
